;
;  Message Box v0.1b  for MenuetOS programs
;
;  Copyright (C) 2003 Crown Soft
;  E-Mail : crown_s@rambler.ru
;
;  Compile with FASM for Menuet
;
;
;============================================================================
;=============================== Example ====================================
;============================================================================
;      ...
;    mov  eax,mb_Information+mb_OK
;    mov  ecx,30*65536+30 ; ecx - window position [x start]*65536+[y start]
;    mov  ebx,Text
;    mov  edx,Title
;    call MsgBox
;
;      ...
;    include "msgbox.inc"
;
;      ...
;    Title db 'MessageBox Title',0
;    Text  db 'Message Box for MenuetOS programs',13
;          db 13
;          db 'Copyright (C) 2003 Crown Soft',13
;          db 'E-Mail : crown_s@rambler.ru',0
;
;      ...
;    draw_window:
;      ...
;    ret
;
;      ...
;
;============================================================================
;============================== Parameters ==================================
;============================================================================
;
; Input:
;   ebx - text (ASCIIZ string, code 13 - newline)
;   edx - title (ASCIIZ string)
;   ecx - window position [x start]*65536+[y start]
;   eax - options=
; 0000 0000  0000 0000  0000 0000  xxxx xxxx b
;                                   
;                                    
;                                     ICO TYPE
;                                         000 - None
;                                         001 - Critical
;                                         010 - Exclamation
;                                         011 - Information
;                                         100 - Question
;                                   
;                                    WINDOW TYPE
;                                          0 - window type II
;                                          1 - skinned window
;                                  
;                                   DRAW "Yes"    BUTTON
;                                   DRAW "No"     BUTTON
;                                   DRAW "OK"     BUTTON
;                                   DRAW "Calcel" BUTTON
;                                              0 - No
;                                              1 - Yes
; Output:
;  eax - exit code (what button was pressed)
;    01 - Close
;    04 - Yes
;    05 - No
;    06 - OK
;    07 - Cancel
;

;  Constants for options
mb_None        =00h
mb_Critical    =01h
mb_Exclamation =02h
mb_Information =03h
mb_Question    =04h

mb_Skinned     =08h

mb_Yes         =10h
mb_No          =20h
mb_OK          =40h
mb_Cancel      =80h

;  Exit Codes
mb_ec_Close    =01h
mb_ec_Yes      =04h
mb_ec_No       =05h
mb_ec_OK       =06h
mb_ec_Cancel   =07h



MessageBox:
messagebox:
MsgBox:
msgbox:
    cmp  [msgbox_exitcode],0
    jz   msgbox_no_thread     ; Maybe msgbox already was shown?
      pushad

      mov  [msgbox_text],ebx
      mov  [msgbox_title],edx
      mov  [msgbox_options],eax
      mov  [msgbox_windowpos],ecx

      call msgbox_CalcWindowGeometry

      mov  edx,esp
      add  edx,0x1000         ; msgbox_thread stack

      mov  ebx,1
      mov  ecx,msgbox_start
      mov  eax,51             ; create msgbox thread
      int  0x40

      mov  [msgbox_exitcode],00

      msgbox_m1_1:
        mov  ebx,1
        mov  eax,23
        int  40h              ; get messages for main program

        cmp  eax,1            ; redraw request ?
        jnz  msgbox_not_redr
          call draw_window
          jmp  msgbox_m1_1
        msgbox_not_redr:
        cmp  eax,2            ; key in buffer ?
        jnz  msgbox_not_key
          int  40h            ; just read it and ignore
          jmp  msgbox_m1_1
        msgbox_not_key:
        cmp  eax,3            ; button in buffer ?
        jnz  msgbox_not_button
          mov  eax,17         ; just read it and ignore
          int  0x40
          jmp  msgbox_m1_1
        msgbox_not_button:

      cmp  [msgbox_exitcode],0
      jz  msgbox_m1_1         ; was msgbox thread closed?
      popad

      movzx eax,[msgbox_exitcode]
    msgbox_no_thread:
ret


msgbox_text    dd ?
msgbox_title   dd ?
msgbox_options dd ?
msgbox_windowpos dd ?

msgbox_exitcode db 0FFh


msgbox_CalcWindowGeometry:
  mov  bx,0        ; TextX
  mov  [msgbox_TextY],0

  mov  edi,[msgbox_text]
  cmp  edi,0
  jz msgbox_TextX0TextY0
    xor  al,al
    mov  ecx,0FFFFh
    repnz scasb
    neg  ecx
    add  ecx,0FFFFh              ; ecx=length [msgbox_text] ASCIIZ text
    mov  [msgbox_TextLength],cx

    mov  edi,[msgbox_text]
    msgbox_m2_2:
      mov  edx,edi
      mov  al,13
      repnz scasb

      mov  eax,edi
      sub  eax,edx
      dec  eax                   ; eax=length string terminated 0Dh code

      cmp  ax,bx
      jna  msgbox_m1_2
        mov  bx,ax
      msgbox_m1_2:
      inc [msgbox_TextY]

      cmp ecx,0
    jnz msgbox_m2_2
  msgbox_TextX0TextY0:
  mov  [msgbox_TextX],bx


  ; Calculating  WindowXS

  mov  ax,bx
  mul  [msgbox_const6]
  test [msgbox_options],07h
  jz  msgbox_NoneIco
    add  ax,45
  msgbox_NoneIco:
  add  ax,20
  mov  [msgbox_LenText],ax


  mov  ax,word [msgbox_options]
  xor  ecx,ecx
  bt   ax,4
  jnc  msgbox_m1_4
    inc  cl
  msgbox_m1_4:
  bt   ax,5
  jnc  msgbox_m2_4
    inc  cl
  msgbox_m2_4:
  bt   ax,6
  jnc  msgbox_m3_4
    inc  cl
  msgbox_m3_4:
  bt   ax,7
  jnc  msgbox_m4_4
    inc  cl
  msgbox_m4_4:       ; cl - number of buttons
;  mov  [NumberOfButtons],cl
  mov ax,cx
  mul [msgbox_const60]
  sub ax,10
  mov [msgbox_LenButtons1],ax
  add ax,20
  mov [msgbox_LenButtons],ax


  xor  eax,eax
  mov  edi,[msgbox_title]
  cmp  edi,0
  jz  msgbox_m12_6
    mov  ecx,256
    repnz scasb                  ; find 00 code in string
    mov  eax,ecx
    neg  eax
    add  eax,256
    dec  eax                     ; eax=length [msgbox_title] ASCIIZ string
  msgbox_m12_6:
  mul  [msgbox_const6]
  add  ax,33
  bt   word [msgbox_options],3
  jnc  msgbox_NotScinned
    add ax,35
  msgbox_NotScinned:

  ; find max of LenTitle, LenButtons, LenText
  cmp  ax,[msgbox_LenButtons]
  ja   msgbox_LenButtons_NotMore
    mov  ax,[msgbox_LenButtons]
  msgbox_LenButtons_NotMore:
  cmp  ax,[msgbox_LenText]
  ja   msgbox_LenText_NotMore
    mov  ax,[msgbox_LenText]
  msgbox_LenText_NotMore:
  mov  [msgbox_WindowXS],ax

  ; Calculating WindowYS
  mov  ax,[msgbox_TextY]
  mul  [msgbox_const10]
  test [msgbox_options],07h
   jz msgbox_NoneIco1
     cmp  ax,32
    ja  msgbox_Ico_NotMore
      mov  ax,32
    msgbox_Ico_NotMore:
  msgbox_NoneIco1:
  mov  [msgbox_TextHeight],ax

  add  ax,60
  mov  [msgbox_WindowYS],ax



  mov  eax,14        ; get screen max
  int  40h

  cmp  [msgbox_WindowYS],ax
  jna  msgbox_NotYMax
    mov  [msgbox_WindowYS],ax
  msgbox_NotYMax:

  sub  ax,[msgbox_WindowYS]
  cmp  word [msgbox_windowpos],ax
  jna  msgbox_NotYSMax
    mov  word [msgbox_windowpos],ax
  msgbox_NotYSMax:



  shr  eax,16
  cmp  [msgbox_WindowXS],ax
  jna  msgbox_NotXMax
    mov  [msgbox_WindowXS],ax
  msgbox_NotXMax:

  sub  ax,[msgbox_WindowXS]
  cmp  word [msgbox_windowpos+2],ax
  jna  msgbox_NotXSMax
    mov  word [msgbox_windowpos+2],ax
  msgbox_NotXSMax:

ret

msgbox_TextLength dw 0
msgbox_TextX dw 0
msgbox_TextY dw 0
msgbox_TextHeight dw 0

msgbox_LenText    dw 0
msgbox_LenButtons dw 0

msgbox_LenButtons1 dw 0

msgbox_WindowXS  dw 0  ; Window size
msgbox_WindowYS  dw 0

msgbox_const60 dw 60
msgbox_const10 dw 10
msgbox_const6  dw 6

;============================================================================
;============================= MsgBox thread ================================
;============================================================================

msgbox_start:                 ; start of execution

  call msgbox_draw_window     ; at first, draw the window

msgbox_still:
  mov  eax,10                 ; wait here for event
  int  0x40

  cmp  eax,1                  ; redraw request ?
  jz   msgbox_start
  cmp  eax,2                  ; key in buffer ?
  jz   msgbox_key
  cmp  eax,3                  ; button in buffer ?
  jz   msgbox_button
jmp  msgbox_still

msgbox_key:                   ; key
  mov  eax,2                  ; just read it and ignore
  int  0x40
jmp  msgbox_still

msgbox_button:                ; button
  mov  eax,17                 ; get id
  int  0x40

  mov  [msgbox_exitcode],ah   ; tell parent prosess about exit
  mov  eax,-1
  int  0x40                   ; close MsgBox thread



;   *********************************************
;   *******  WINDOW DEFINITIONS AND DRAW ********
;   *********************************************


msgbox_draw_window:
    mov  ecx,msgbox_colours        ; pointer to table
    mov  edx,msgbox_end_colours-msgbox_colours  ; number of bytes to get
    mov  ebx,3                     ; get define window colors
    mov  eax,48                    ; get general window properties
    int  0x40

    cld

    mov  eax,12                    ; function 12:tell os about windowdraw
    mov  ebx,1                     ; 1, start of draw
    int  0x40

    ; *** DRAW WINDOW ***
    mov  bx,word [msgbox_windowpos+2]
    shl  ebx,16
    mov  bx,[msgbox_WindowXS]      ; [x start] *65536 + [x size]
    mov  cx,word [msgbox_windowpos]
    shl  ecx,16
    mov  cx,[msgbox_WindowYS]      ; [y start] *65536 + [y size]

    mov  edx,[msgbox_cl_work]      ; color of work area RRGGBB
    mov  esi,[msgbox_cl_grab]      ; color of grab bar  RRGGBB
    add  esi,80000000h
    mov  edi,[msgbox_cl_frame]     ; color of frames    RRGGBB
    xor  eax,eax                   ; function 0 : define and draw window
    bt   word [msgbox_options],3
    jc   msgbox_SkinnedWindow
      add  edx,02000000h
      int  0x40

      ; *** CLOSE BUTTON ***
      sub  bx,19                   ; bx = [x start]
      shl  ebx,16
      mov  bx,12                   ; [x start]*65536+[x size]

      mov  ecx,4*65536+12          ; [y start]*65536+[y size]
      mov  edx,1                   ; button id
      mov  esi,[msgbox_cl_grab_button]  ; button color RRGGBB
      mov  eax,8                   ; function 8 : define and draw button
    jmp  msgbox_m14
    msgbox_SkinnedWindow:
      add  edx,03000000h
    msgbox_m14:
    int  0x40

    ; *** WINDOW TITLE ***
    mov  edi,[msgbox_title]
    cmp  edi,0
    jz  msgbox_m12
      xor  al,al
      mov  ecx,256
      repnz scasb                  ; find 00 code in string
      neg  ecx
      add  ecx,256
      dec  ecx                     ; ecx=length [msgbox_title] ASCIIZ string
      mov  esi,ecx

      mov  ebx,8*65536+8           ; [x start] *65536 + [y start]
      mov  ecx,[msgbox_cl_grab_text]  ; color of text RRGGBB
      mov  edx,[msgbox_title]      ; pointer to text beginning
      mov  eax,4                   ; function 4 : write text to window
      int  0x40
    msgbox_m12:


    ; *** BUTTONS ***
    mov  cx,[msgbox_WindowYS]
    sub  cx,25                     ; [y start]=[WindowYS]-25
    shl  ecx,16
    mov  cx,14                     ; [y start]*65536+[y size]

    mov  bx,[msgbox_WindowXS]
    sub  bx,[msgbox_LenButtons1]
    shr  bx,1                      ; [x start]=([WindowXS]-[LenButtons1])/2
    shl  ebx,16
    mov  bx,50                     ; [x start]*65536+[x size]

    mov  esi,[msgbox_cl_work_button]  ; button color

    mov  edx,4
    msgbox_NextButton:
      bt   word [msgbox_options],dx
      jnc  msgbox_NotButton
        pushad

        mov  eax,8                 ; function 8 : define and draw button
        int  0x40

        add  ebx,10*65536          ; Buttons text
        shr  ecx,16
        mov  bx,cx
        add  bx,4                  ; [x start]*65536 + [y start]

        mov  eax,edx
        sub  eax,4
        mul  [msgbox_bt_labels_len]
        add  eax,msgbox_bt_labels
        mov  edx,eax               ; pointer to text beginning
        mov  esi,6                 ; [bt_labels_len] = text length

        mov  ecx,[msgbox_cl_work_button_text] ; text color 0x00RRGGBB
        mov  eax,4                 ; draw info text with function 4
        int  0x40

        popad

        add  ebx,60*65536          ; [x start] *65536 + [x size]
      msgbox_NotButton:

      inc  dl
      cmp  dl,8
    jnz  msgbox_NextButton

    ; *** TEXT ***
    mov  edi,[msgbox_text]
    cmp  edi,0
    jz msgbox_NotDrawText
      movzx  ecx,[msgbox_TextLength]

      mov  ebx,11*65536+30         ; [x start]*65536+[y start]
      test [msgbox_options],07h
      jz  msgbox_NoneIco2
        add  ebx,45*65536+0        ; [x start]*65536+[y start]
      msgbox_NoneIco2:

      mov ax,[msgbox_TextY]
      mul [msgbox_const10]
      neg ax
      add ax,[msgbox_TextHeight]
      shr ax,1                     ; ax=(TextHeight-TextY*10)/2
      add bx,ax                    ; ebx=[x start]*65536+[y start]

      msgbox_m2_3:
        mov  edx,edi               ; pointer to text beginning
        mov  al,13
        repnz scasb                ; find 0Dh

        mov  esi,edi
        sub  esi,edx
        dec  esi                   ; text length

        push ecx
        mov  ecx,[msgbox_cl_work_button_text] ; text color 0x00RRGGBB
        mov  eax,4                 ; draw text with function 4
        int  0x40
        pop  ecx

        add  ebx,10

        cmp ecx,0
      jnz msgbox_m2_3
    msgbox_NotDrawText:


    ; *** ICO ***
    mov  di,[msgbox_TextHeight]
    sub  di,32
    shr  di,1
    add  di,30                     ; [y start]=(TextHeight-32)/2+30
    shl  edi,16
    mov  di,15                     ; [y start]*65536+[x start]

    mov  eax,[msgbox_options]
    and  eax,00000007h
    jz   msgbox_m10
      dec  eax                     ; eax - Ico Number
      call msgbox_UnpackIco
    msgbox_m10:

    mov  eax,12                    ; function 12:tell os about windowdraw
    mov  ebx,2                     ; 2, end of draw
    int  0x40
ret


msgbox_colours:
  msgbox_cl_frame              dd ?
  msgbox_cl_grab               dd ?
  msgbox_cl_grab_button        dd ?
  msgbox_cl_grab_button_text   dd ?
  msgbox_cl_grab_text          dd ?
  msgbox_cl_work               dd ?
  msgbox_cl_work_button        dd ?
  msgbox_cl_work_button_text   dd ?
;  msgbox_cl_work_text          dd ?
;  msgbox_cl_work_graph         dd ?
msgbox_end_colours:


;==================== draw pictures number eax ==============================
msgbox_UnpackIco:
   mov esi,[msgbox_pict+eax*4]

   lodsb                     ; al - mask color
   mov  bl,al                ; bl - mask color

   xor  edx,edx              ; edx=0000YYXXh
   xor  ecx,ecx
   msgbox_m2:
     xor  eax,eax
     lodsb                   ; load byte 0CNh
     mov  cl,al
     and  cl,0Fh
     shr  al,4               ; cl=N=number pixels  al=C=color

     cmp  cl,ch              ; ch=00h
     jz   msgbox_m1          ; if N=0 then exit

     msgbox_m3:
       cmp  al,bl            ; is color mask?
       jz   msgbox_m5
         pushad

         movzx  ebx,dl       ; x
         add    bx,di        ; x
         movzx  ecx,dh       ; y
         shr    edi,16
         add    cx,di        ; y

         mov  edx,[msgbox_coltbl+eax*4]  ; color
         mov  eax,1
         int  40h

         popad
       msgbox_m5:

       inc  dx
       bt   dx,5             ; if  XX=32  then  XX=0 YY=YY+1
       jnc  msgbox_m6
         xor  dl,dl
         inc  dh
       msgbox_m6:
     loop msgbox_m3
   jmp msgbox_m2

   msgbox_m1:
ret
;============================================================================


; DATA AREA


msgbox_bt_labels_len dw 6
msgbox_bt_labels  db ' Yes  '
                  db '  No  '
                  db '  OK  '
                  db 'Cancel'


msgbox_coltbl dd 000000h,800000h,008000h,808000h
              dd 000080h,800080h,008080h,0C0C0C0h
              dd 808080h,0FF0000h,00FF00h,0FFFF00h
              dd 0000FFh,0FF00FFh,00FFFFh,0FFFFFFh

msgbox_pict   dd msgbox_CriticalIco       ; 001
              dd msgbox_ExclamationIco    ; 010
              dd msgbox_InformationIco    ; 011
              dd msgbox_QuestionIco       ; 100
              dd msgbox_CriticalIco       ; 101 -+
              dd msgbox_CriticalIco       ; 110  I  for error in options
              dd msgbox_CriticalIco       ; 111 -+

;----------- Compressed Icons -----------

msgbox_CriticalIco db 0 ; this color will background
  db 00Bh,018h,00Fh,006h,013h,098h,013h,00Fh ; each byte is 0CNh
  db 002h,011h,09Eh,011h,00Eh,012h,09Fh,091h ;   there C - color
  db 012h,00Bh,011h,09Fh,095h,011h,009h,011h ;         N - number pixels
  db 09Fh,097h,011h,008h,011h,09Fh,097h,011h ;
  db 081h,006h,011h,096h,0F1h,09Ah,0F1h,096h ; byte 0X0h - end of picture
  db 011h,081h,004h,011h,096h,0F3h,098h,0F3h
  db 096h,011h,004h,011h,095h,0F5h,096h,0F5h
  db 095h,011h,081h,003h,011h,096h,0F5h,094h
  db 0F5h,096h,011h,082h,001h,011h,098h,0F5h
  db 092h,0F5h,098h,011h,081h,001h,011h,099h
  db 0FAh,099h,011h,081h,001h,011h,09Ah,0F8h
  db 09Ah,011h,082h,011h,09Bh,0F6h,09Bh,011h
  db 082h,011h,09Bh,0F6h,09Bh,011h,082h,011h
  db 09Ah,0F8h,09Ah,011h,082h,011h,099h,0FAh
  db 099h,011h,082h,011h,098h,0F5h,092h,0F5h
  db 098h,011h,082h,001h,011h,096h,0F5h,094h
  db 0F5h,096h,011h,083h,001h,011h,095h,0F5h
  db 096h,0F5h,095h,011h,083h,001h,011h,096h
  db 0F3h,098h,0F3h,096h,011h,082h,003h,011h
  db 096h,0F1h,09Ah,0F1h,096h,011h,083h,004h
  db 011h,09Fh,097h,011h,084h,004h,011h,09Fh
  db 097h,011h,083h,006h,011h,09Fh,095h,011h
  db 083h,008h,012h,09Fh,091h,012h,084h,009h
  db 081h,011h,09Eh,011h,085h,00Bh,081h,013h
  db 098h,013h,085h,00Eh,082h,018h,086h,00Fh
  db 002h,08Eh,00Fh,006h,088h,000h

msgbox_ExclamationIco db 1
  db 01Dh,033h,01Fh,01Dh,031h,0B2h,071h,001h
  db 01Fh,01Bh,031h,0B4h,071h,001h,081h,01Fh
  db 019h,031h,0B5h,001h,082h,01Fh,017h,031h
  db 0B6h,071h,001h,082h,01Fh,016h,031h,0B7h
  db 001h,082h,01Fh,015h,031h,0B8h,071h,001h
  db 082h,01Fh,014h,031h,0B9h,001h,082h,01Fh
  db 013h,031h,0BAh,071h,001h,082h,01Fh,012h
  db 031h,0B3h,071h,003h,071h,0B3h,001h,082h
  db 01Fh,011h,031h,0B4h,005h,0B3h,071h,001h
  db 082h,01Fh,031h,0B4h,005h,0B4h,001h,082h
  db 01Eh,031h,0B5h,005h,0B4h,071h,001h,082h
  db 01Dh,031h,0B5h,005h,0B5h,001h,082h,01Ch
  db 031h,0B6h,005h,0B5h,071h,001h,082h,01Bh
  db 031h,0B6h,031h,004h,0B6h,001h,082h,01Ah
  db 031h,0B7h,071h,003h,071h,0B6h,071h,001h
  db 082h,019h,031h,0B8h,003h,0B8h,001h,082h
  db 018h,031h,0B9h,031h,001h,031h,0B8h,071h
  db 001h,082h,017h,031h,0B9h,071h,001h,071h
  db 0B9h,001h,082h,016h,031h,0BBh,001h,0BAh
  db 071h,001h,082h,015h,031h,0BFh,0B8h,001h
  db 082h,014h,031h,0BBh,071h,002h,071h,0B9h
  db 071h,001h,082h,013h,031h,0BBh,004h,0BAh
  db 001h,082h,012h,031h,0BCh,004h,0BAh,071h
  db 001h,082h,011h,031h,0BCh,071h,002h,071h
  db 0BBh,001h,082h,011h,031h,0BFh,0BCh,001h
  db 083h,031h,0BFh,0BBh,071h,001h,083h,011h
  db 031h,0BFh,0B9h,071h,001h,084h,012h,031h
  db 00Fh,009h,085h,014h,08Fh,08Ch,016h,08Fh
  db 08Ah,000h

msgbox_QuestionIco db 1
  db 01Bh,088h,01Fh,016h,083h,071h,0F6h,071h
  db 083h,01Fh,011h,082h,071h,0FCh,071h,082h
  db 01Dh,081h,071h,0FFh,0F1h,071h,081h,01Bh
  db 081h,0FFh,0F5h,001h,019h,081h,0F7h,071h
  db 0C6h,071h,0F7h,001h,017h,081h,0F7h,071h
  db 0C1h,071h,0F2h,0C4h,071h,0F7h,001h,015h
  db 081h,071h,0F7h,0C2h,0F4h,0C4h,0F7h,071h
  db 001h,014h,081h,0F8h,0C4h,0F2h,0C4h,0F8h
  db 001h,081h,012h,081h,071h,0F8h,0C4h,0F1h
  db 071h,0C4h,0F8h,071h,001h,081h,011h,081h
  db 0F9h,071h,0C2h,071h,0F1h,0C4h,0FAh,001h
  db 081h,011h,081h,0FDh,071h,0C3h,0FBh,001h
  db 083h,0FDh,0C3h,0FCh,001h,083h,0FDh,0C2h
  db 071h,0FCh,001h,083h,0FDh,0C2h,0FDh,001h
  db 083h,071h,0FFh,0FBh,071h,001h,082h,011h
  db 081h,0FBh,071h,0C2h,071h,0FBh,001h,083h
  db 011h,081h,071h,0FAh,0C4h,0FAh,071h,001h
  db 083h,012h,081h,0FAh,0C4h,0FAh,001h,083h
  db 014h,001h,0F9h,071h,0C2h,071h,0F9h,001h
  db 084h,015h,001h,0FFh,0F5h,001h,084h,017h
  db 001h,071h,0FFh,0F1h,071h,001h,084h,019h
  db 002h,071h,0FCh,071h,002h,084h,01Bh,081h
  db 003h,071h,0F6h,071h,003h,085h,01Dh,083h
  db 003h,071h,0F3h,001h,087h,01Fh,011h,084h
  db 001h,0F3h,001h,085h,01Fh,016h,081h,001h
  db 0F3h,001h,082h,01Fh,01Bh,001h,0F2h,001h
  db 082h,01Fh,01Ch,001h,0F1h,001h,082h,01Fh
  db 01Dh,002h,082h,01Fh,01Eh,083h,01Fh,01Fh
  db 082h,000h

msgbox_InformationIco db 1
  db 01Bh,088h,01Fh,016h,083h,071h,0F6h,071h
  db 083h,01Fh,011h,082h,071h,0FCh,071h,082h
  db 01Dh,081h,071h,0FFh,0F1h,071h,081h,01Bh
  db 081h,0F7h,071h,0C4h,071h,0F7h,001h,019h
  db 081h,0F8h,0C6h,0F8h,001h,017h,081h,0F9h
  db 0C6h,0F9h,001h,015h,081h,071h,0F9h,071h
  db 0C4h,071h,0F9h,071h,001h,014h,081h,0FFh
  db 0FBh,001h,081h,012h,081h,071h,0FFh,0FBh
  db 071h,001h,081h,011h,081h,0FAh,0C7h,0FBh
  db 001h,081h,011h,081h,0FCh,0C5h,0FBh,001h
  db 083h,0FCh,0C5h,0FBh,001h,083h,0FCh,0C5h
  db 0FBh,001h,083h,0FCh,0C5h,0FBh,001h,083h
  db 071h,0FBh,0C5h,0FAh,071h,001h,082h,011h
  db 081h,0FBh,0C5h,0FAh,001h,083h,011h,081h
  db 071h,0FAh,0C5h,0F9h,071h,001h,083h,012h
  db 081h,0F8h,0C9h,0F7h,001h,083h,014h,001h
  db 0FFh,0F7h,001h,084h,015h,001h,0FFh,0F5h
  db 001h,084h,017h,001h,071h,0FFh,0F1h,071h
  db 001h,084h,019h,002h,071h,0FCh,071h,002h
  db 084h,01Bh,081h,003h,071h,0F6h,071h,003h
  db 085h,01Dh,083h,003h,071h,0F3h,001h,087h
  db 01Fh,011h,084h,001h,0F3h,001h,085h,01Fh
  db 016h,081h,001h,0F3h,001h,082h,01Fh,01Bh
  db 001h,0F2h,001h,082h,01Fh,01Ch,001h,0F1h
  db 001h,082h,01Fh,01Dh,002h,082h,01Fh,01Eh
  db 083h,01Fh,01Fh,082h,000h
